@@ -4,20 +4,23 @@ from lxml import html
 from requests import exceptions
 import simplejson
 
+from . import errors
 from . import helpers
 from . import util
 from .xpath import XPathBuilder, xpb
 
 
 log = logging.getLogger(__name__)
-
 thread_element_xpath = XPathBuilder(relative=False).li.with_classes('thread',
                                                                     'message')
+
+
 def ThreadFetcher(session, mailbox_number):
     return util.FetchMarshall(
         ThreadHTMLFetcher(session, mailbox_number),
         util.SimpleProcessor(
-            session, lambda elem: MessageThread(session, elem), thread_element_xpath
+            session, lambda elem: MessageThread(session, elem),
+            thread_element_xpath
         )
     )
 
@@ -83,6 +86,12 @@ class MessageFetcher(object):
         return self._message_elements_xpb.apply_(self.messages_tree)
 
 
+_base_timestamp_xpb = xpb.span.with_class('timestamp').\
+                      span.with_class('fancydate')
+_timestamp_xpb = _base_timestamp_xpb.text_
+_em_timestamp_xpb = _base_timestamp_xpb.em.text_
+
+
 class Message(object):
     """Represent a message sent on okcupid.com"""
 
@@ -117,25 +126,26 @@ class Message(object):
                 if 'from_me' in self._message_element.attrib['class']
                 else self._message_thread.user_profile)
 
+    _content_xpb = xpb.div.with_class('message_body').text_
     @util.cached_property
     def content(self):
         """
         :returns: The text body of the message.
         """
-        message = xpb.div.with_class('message_body').apply_(self._message_element)
-        content = None
-        if message:
-            message = message[0]
-            content = message.text_content().replace(' \n \n', '\n').strip()
-        return content
+        try:
+            message = self._content_xpb.one_(self._message_element)
+        except IndexError:
+            pass
+        else:
+            return message.strip()
 
-    _timestamp_xpb = xpb.span.with_class('timestamp').span.with_class('fancydate')
     @util.cached_property
     def time_sent(self):
-        fancydate_text = self._timestamp_xpb.select_attribute_(
-            'id', self._message_element
-        )[0]
-        return helpers.parse_fancydate(fancydate_text)
+        try:
+            timestamp_text = _timestamp_xpb.one_(self._message_element)
+        except IndexError:
+            timestamp_text = _em_timestamp_xpb.one_(self._message_element)
+        return helpers.parse_date_updated(timestamp_text)
 
     def __repr__(self):
         return '<{0}: {1} sent {2} "{3}{4}">'.format(
@@ -151,12 +161,26 @@ class MessageThread(object):
     """Represent a message thread between two users."""
 
     @classmethod
-    def delete_threads(cls, session, thread_ids, authcode=None):
+    def delete_threads(cls, session, thread_ids_or_threads, authcode=None):
+        """
+        :param session: A logged in :class:`~okcupyd.session.Session`.
+        :param thread_ids_or_threads: A list whose members are either
+                                      :class:`~.MessageThread` instances
+                                      or okc_ids of message threads.
+        :param authcode: Authcode to use for this request. If none is provided
+                         A request to the logged in user's messages page
+                         will be made to retrieve one.
+        """
+        thread_ids = [thread.id if isinstance(thread, cls) else thread
+                      for thread in thread_ids_or_threads]
         if not authcode:
-            authcode = helpers.get_authcode(html.fromstring(session.okc_get('messages').content))
+            authcode = helpers.get_authcode(html.fromstring(
+                session.okc_get('messages').content
+            ))
         data = {'access_token': authcode,
                 'threadids': simplejson.dumps(thread_ids)}
-        return session.okc_delete('apitun/messages/threads', params=data, data=data)
+        return session.okc_delete('apitun/messages/threads',
+                                  params=data, data=data)
 
     def __init__(self, session, thread_element):
         self._session = session
@@ -187,8 +211,8 @@ class MessageThread(object):
             except:
                 pass
 
-    _correspondent_xpb = xpb.div.with_class('inner').a.with_class('photo').\
-                             img.select_attribute_('alt')
+    _correspondent_xpb = xpb.div.with_class('inner').a.with_class('open').\
+                         span.with_class('subject').text_
 
     @util.cached_property
     def correspondent(self):
@@ -196,7 +220,10 @@ class MessageThread(object):
         :returns: The username of the user with whom the logged in user is
                   conversing in this :class:`~.MessageThread`.
         """
-        return self._correspondent_xpb.apply_(self._thread_element)[0].split()[-1]
+        try:
+            return self._correspondent_xpb.one_(self._thread_element).strip()
+        except IndexError:
+            raise errors.NoCorrespondentError()
 
     @util.cached_property
     def read(self):
@@ -210,13 +237,11 @@ class MessageThread(object):
     def date(self):
         return self.datetime.date()
 
-    _timestamp_xpb = xpb.span.with_class('timestamp').span.with_class('fancydate')
     @util.cached_property
     def datetime(self):
-        fancydate_text = self._timestamp_xpb.select_attribute_(
-            'id', self._thread_element
-        )[0]
-        return helpers.parse_fancydate(fancydate_text)
+        return helpers.parse_date_updated(
+            _timestamp_xpb.one_(self._thread_element)
+        )
 
     @property
     def with_deleted_user(self):
@@ -253,7 +278,8 @@ class MessageThread(object):
     def correspondent_profile(self):
         """
         :returns: The :class:`~okcupyd.profile.Profile` of the user with whom
-                  the logged in user is conversing in this :class:`~.MessageThread`.
+                  the logged in user is conversing in this
+                  :class:`~.MessageThread`.
         """
         return self._session.get_profile(self.correspondent)
 
@@ -279,7 +305,8 @@ class MessageThread(object):
         :returns: Whether or not the :class:`~.MessageThread`. has received a
                   response.
         """
-        return any(message.sender != self.initiator for message in self.messages)
+        return any(message.sender != self.initiator
+                   for message in self.messages)
 
     def delete(self):
         """Delete this thread for the logged in user."""
